@@ -1,4 +1,7 @@
-__version__ = '0.10'
+import contextlib
+
+
+__version__ = '0.11.0'
 
 
 def description(message):
@@ -57,9 +60,21 @@ def included_context(message):
     pass
 
 
+@contextlib.contextmanager
 def before():
     pass
 
 
+@contextlib.contextmanager
+def before_all():
+    pass
+
+
+@contextlib.contextmanager
 def after():
     pass
+
+
+@contextlib.contextmanager
+def after_all():
+    pass
